﻿
using System.Text;
using System;
using System.Collections;
using maddox.game;
using maddox.game.world;
using maddox.GP;
using System.Collections.Generic;
using System.IO;
using System.Diagnostics;
using System.ComponentModel;
using System.Threading;


public class Mission : AMission
{

   public bool BlueWon = false;
   public bool RedWon = false;

   private static string userdocpath = Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments);
   private static string CLODO_FILE_PATH = userdocpath + @"\1C SoftClub\il-2 sturmovik cliffs of dover - mod\";
   private static string FILE_PATH = @"missions\multi\dogfight\Beams1\Beams1.mis"; // adjust to your needs
   private static string MISSION_FILE = CLODO_FILE_PATH + FILE_PATH;

   Random random = new Random();


   public Dictionary<AiAirport, double> AirfieldTargets = new Dictionary<AiAirport, double>(); //Dictionary to hold the AirfieldTargets and weight of Bombs needed to knock out.
   public Dictionary<AiAirport, string> AirfieldTargetsName = new Dictionary<AiAirport, string>(); //Dictionary to hold the AirfieldTargets Name.
   public Dictionary<AiAirport, double> AirfieldTargetsDamage = new Dictionary<AiAirport, double>(); //Dictionary to hold the AirfieldTargets and weight of Bombs taken.
   public Dictionary<AiAirport, bool> AirfieldTargetsState = new Dictionary<AiAirport, bool>(); //Dictionary to hold the AirfieldTargets and overall state True/False.





   public void SetAirfieldTargets()
   {
       foreach (AiAirport ap in GamePlay.gpAirports()) //Loop through all airfields in the game
       {
           if (ap.Name().Contains("Ramsgate"))
           { //if the name contains "Ramsgate" then add it - change to reflect the name you want to use
               AirfieldTargets.Add(ap, 10000); //Adds to airfieldstargets the AiAirport and the bomb weight of x kgs
               AirfieldTargetsDamage.Add(ap, 0); //Adds AiAirport and zero damage done - you could start with a damaged airfield if you wanted
               AirfieldTargetsState.Add(ap, false); //Adds AiAirport and false to say it's still functional
               AirfieldTargetsName.Add(ap, "Ramsgate");// adds AiAirport and the "display Name" we're using in the game for messages etc.
           }

           //You'd just repeat this code block for each airfield you wanted to add as a target.
       }
   }
    
    public override void OnBattleStarted()
    {
        base.OnBattleStarted();
        MissionNumberListener = -1;
	SetAirfieldTargets();
    }

    public Player[] ToAll()
    {
        try
        {
            List<Player> players = new List<Player>();
            foreach (Player player in GamePlay.gpRemotePlayers()) { players.Add(player); }
            return players.ToArray();
        }
        catch (Exception e)
        {
            Console.WriteLine("Error: [ToAll] " + e.Message);
            return null;
        }
    }
    public Player[] ToArmy(int army)
    #region returns an array of players in the named army
    {
        try
        {
            List<Player> players = new List<Player>();
            foreach (Player p in GamePlay.gpRemotePlayers())
            {
                if (p.Army() == army) players.Add(p);
            }
            return players.ToArray();
        }
        catch (Exception e)
        {
            Console.WriteLine("Error: [ToArmy] " + e.Message);
            return null;
        }
    }
    #endregion

    
    int InitialBlueObjectiveCount = 0;


    int BlueObjective1 = 10;//Ramsgate

 
    const string Objective_AA = "  RAF Ramsgate,";



    string Objective_Total_Blue = "";




    private void sendScreenMessageTo(int army, string msg, object[] parms)
    {
        List<Player> Players = new List<Player>();

        //Singleplayer or Dedi Server
        if (GamePlay.gpPlayer() != null)
        {
            if (GamePlay.gpPlayer().Army() == army || army == -1)
                Players.Add(GamePlay.gpPlayer());
        } // Multiplayer
        if (GamePlay.gpRemotePlayers() != null || GamePlay.gpRemotePlayers().Length > 0)
        {
            foreach (Player p in GamePlay.gpRemotePlayers())
            {
                if (p.Army() == army || army == -1)
                    Players.Add(p);
            }
        }
        if (Players != null && Players.Count > 0)
            GamePlay.gpHUDLogCenter(Players.ToArray(), msg, parms);
    }


    private void sendChatMessageTo(int army, string msg, object[] parms)
    {
        List<Player> Players = new List<Player>();

        //Singleplayer or Dedi Server
        if (GamePlay.gpPlayer() != null)
        {
            if (GamePlay.gpPlayer().Army() == army || army == -1)
                Players.Add(GamePlay.gpPlayer());
        } // Multiplayer
        if (GamePlay.gpRemotePlayers() != null || GamePlay.gpRemotePlayers().Length > 0)
        {
            foreach (Player p in GamePlay.gpRemotePlayers())
            {
                if (p.Army() == army || army == -1)
                    Players.Add(p);
            }
        }
        if (Players != null && Players.Count > 0)
            GamePlay.gpLogServer(Players.ToArray(), msg, parms);
    }



 public override void OnBombExplosion(string title, double mass, Point3d pos, AiDamageInitiator initiator, int eventArgInt)
    {
   
        base.OnBombExplosion(title, mass, pos, initiator, eventArgInt);

        foreach (AiAirport ap in AirfieldTargets.Keys)
        {
            if (AirfieldTargetsDamage[ap] >= AirfieldTargets[ap])
            {//damage greater than or equal to that required to knock out so no need to add or further process

            }
            else
            {
                //Damage not greater than or equal to so need check if bomb fell inside radius and if so increment up
                if (ap != null & ap.Pos().distance(ref pos) <= ap.FieldR())
                {
                    AirfieldTargetsDamage[ap] = AirfieldTargetsDamage[ap] + mass;
                    string sPercentDamage = null;
                    double dPercentDamage = (AirfieldTargetsDamage[ap] / AirfieldTargets[ap] * 100);
                    sPercentDamage = dPercentDamage.ToString("0");
                    GamePlay.gpHUDLogCenter(AirfieldTargetsName[ap] + " is " + sPercentDamage + "% destroyed");
		    ///GamePlay.gpHUDLogCenter(AirfieldTargetsName[ap] + " is hit with " + AirfieldTargetsDamage[ap] + "kg of bombs");

                    if ((AirfieldTargetsDamage[ap] >= AirfieldTargets[ap]) && (AirfieldTargetsName[ap].Contains("Ramsgate")))
                    {
                           LoadAirfieldSpawns(); //loads airfield spawns and removes inactive airfields.
			   InitialBlueObjectiveCount = InitialBlueObjectiveCount + BlueObjective1;
                           GamePlay.gpHUDLogCenter("Ramsgate is out of action!!!");
                           double initTime = 0.0;
                           Timeout(initTime += 10, () =>
                             {
                               GamePlay.gpLogServer(null, "Ramsgate is out of action!!!", new object[] { });
                               Objective_Total_Blue += (Objective_AA);
                             });
	            }               

                    
                }

            }
        }
    }



    public void LoadAirfieldSpawns ()
    {

        foreach (AiBirthPlace bp in GamePlay.gpBirthPlaces())

        {  
            bp.destroy();//Removes all spawnpoints
        }
        GamePlay.gpPostMissionLoad("missions/multi/dogfight/Beams1/nondestroyable.mis");

       foreach (AiAirport ap in AirfieldTargets.Keys)
	{
        if(AirfieldTargetsDamage[ap] < AirfieldTargets[ap]) 
		{
            //Airfield still active so load mission
            GamePlay.gpPostMissionLoad("missions/multi/dogfight/Beams1/"+AirfieldTargetsName[ap]+".mis");
        	}
        }
    }


}
